@@ -23,6 +23,8 @@ import json
 import os
 import sys
 
+from .qtapi import qt_api
+
 try:
     from taurus.external.qt import Qt
 except Exception:
@@ -219,6 +221,8 @@ class Selector(Qt.QDialog, TaurusBaseWidget):
             settings.value('Preferences/FontSize', self.fontSize))
         self.displayStatus = int(
             settings.value('Preferences/DisplayStatus', 2))
+        self.scanFileExtStatus = int(
+            settings.value('Preferences/ScanFileExtStatus', 2))
         self.cnfFile = str(settings.value("Selector/CnfFile", "./"))
 
         self.__addButtonBoxes()
@@ -308,6 +312,11 @@ class Selector(Qt.QDialog, TaurusBaseWidget):
         if self.__doortoupdateFlag:
             self.updateDoorName(self.__door)
 
+        self.__scanFileExtStatusChanged(int(
+            settings.value('Preferences/ScanFileExtStatus', 2)))
+        self.ui.fileExtScanCheckBox.setChecked(
+            self.scanFileExtStatus != 0)
+
         self.__settingsloaded = True
         self.__skipconfig = False
         logger.debug("settings END")
@@ -417,6 +426,7 @@ class Selector(Qt.QDialog, TaurusBaseWidget):
         self.ui.rowMaxSpinBox.setValue(self.rowMax)
         self.ui.fontSizeSpinBox.setValue(self.fontSize)
         self.ui.statusCheckBox.setChecked(self.displayStatus != 0)
+        self.ui.fileExtScanCheckBox.setChecked(self.scanFileExtStatus != 0)
 
     def __hideWidgets(self):
         """ hides widgets according to set user mode
@@ -473,6 +483,8 @@ class Selector(Qt.QDialog, TaurusBaseWidget):
         self.ui.fontSizeSpinBox.editingFinished.connect(self.resetRows)
         self.ui.statusCheckBox.stateChanged.connect(
             self.__displayStatusChanged)
+        self.ui.fileExtScanCheckBox.stateChanged.connect(
+            self.__scanFileExtStatusChanged)
 
         self.detectors.dirty.connect(self.setDirty)
         self.preferences.dirty.connect(self.setDirty)
@@ -561,6 +573,9 @@ class Selector(Qt.QDialog, TaurusBaseWidget):
         settings.setValue(
             "Preferences/DisplayStatus",
             (2 if self.ui.statusCheckBox.isChecked() else 0))
+        settings.setValue(
+            "Preferences/ScanFileExtStatus",
+            (2 if self.ui.fileExtScanCheckBox.isChecked() else 0))
         settings.setValue(
             "Preferences/Groups",
             (str(self.preferences.mgroups)))
@@ -1179,6 +1194,28 @@ class Selector(Qt.QDialog, TaurusBaseWidget):
         self.displayStatus = state
         self.setDirty(self.__dirty)
 
+    @Qt.pyqtSlot(int)
+    def __scanFileExtStatusChanged(self, state):
+        """  scan file extension status in buttonbox
+
+        :param state:  status state
+        :type index: :obj:`int`
+        """
+        self.scanFileExtStatus = state
+        if state:
+            self.ui.fileExtScanLineEdit.show()
+            self.ui.fileExtScanLabel.show()
+            self.state.scanFile = self.storage.fileNames(False, False)
+            # self.storage.apply()
+            self.storage.updateForm(True)
+        else:
+            self.ui.fileExtScanLineEdit.hide()
+            self.ui.fileExtScanLabel.hide()
+            self.state.scanFile = self.storage.fileNames(False, True)
+            # self.storage.apply()
+            self.storage.updateForm(False)
+        self.setDirty(self.__dirty)
+
     def closeApply(self):
         """ close action for apply command """
         self.storage.showErrors()
@@ -1242,6 +1279,10 @@ def main():
         from taurus.external.qt import Qt
     except Exception:
         from taurus.qt import Qt
+    try:
+        from taurus.external.qt import __qt
+    except Exception:
+        from taurus.qt import __qt
     Qt.QCoreApplication.setAttribute(Qt.Qt.AA_X11InitThreads)
     Qt.QResource.registerResource(
         os.path.join(qrc.__path__[0], "resources.rcc"))
@@ -1258,6 +1299,7 @@ def main():
     door = None
     switch = True
 
+    logger.debug("Using %s" % qt_api)
     if standalone:
         import taurus.core.util.argparse
         parser = taurus.core.util.argparse.get_taurus_parser()
@@ -1304,9 +1346,18 @@ def main():
         (options, _) = parser.parse_args()
         if options.style:
             app.setStyle(options.style)
+
         server = options.server
         if options.stylesheet:
-            app.setStyle(options.stylesheet)
+            app.setStyleSheet(options.stylesheet)
+        elif options.style == "cleanlooks":
+            pyqtver = __qt.PYQT_VERSION.split(".")
+            if pyqtver and pyqtver[0] == "4":
+                # fix for cleanlooks tooltip colors
+                app.setStyleSheet(
+                    "QToolTip{ color: black; background-color: white; }"
+                )
+
         if options.mode:
             umode = options.mode
         else:
